@@ -20,6 +20,8 @@ from symbl_rest.api.members_api import MembersApi
 from symbl_rest.api.messages_api import MessagesApi
 from symbl_rest.api.metric_api import MetricApi
 from symbl_rest.api.metric_entry_api import MetricEntryApi
+from symbl_rest.api.put_members_information_api import PutMembersInformationApi
+from symbl_rest.api.put_speaker_events_api import PutSpeakerEventsApi
 from symbl_rest.api.questions_api import QuestionsApi
 from symbl_rest.api.topics_api import TopicsApi
 from symbl_rest.api.trackers_api import TrackersApi
